const tsNone = 0,
    tsLibrary = 1,
    tsCDUniverse = 2,
    tsGoogle = 3,
    tsWikipedia = 4,
    tsHDTracks = 5,
    tsAmzItaly = 6,
    tsAmzSpain = 7,
    tsAmzChina = 8,
    tsYouTube = 9;

window.TrackShortcuts = [
    {
        id: 1,
        order: 10,
        icon: 'google',
        title: 'Google',
        execute: function (type, prop, item) {
            app.utils.web.openSearchWeb(tsGoogle, type, item);
        }
    },
    {
        id: 2,
        order: 20,
        icon: 'wikipedia',
        title: 'Wikipedia',
        execute: function (type, prop, item) {
            app.utils.web.openSearchWeb(tsWikipedia, type, item);
        }
    },
    {
        id: 3,
        order: 30,
        icon: 'youtube',
        title: 'YouTube',
        execute: function (type, prop, item) {
            app.utils.web.openSearchWeb(tsYouTube, type, item);
        }
    },
    {
        id: 4,
        order: 40,
        icon: 'spotify',
        title: 'Spotify',
        execute: function (type, prop, item) {

            var checkArtist = (artist) => {
                var res = app.utils.getLingBase(artist);
                if (res.toLowerCase() == 'various')
                    return ''
                else
                if (res.toLowerCase() == 'various artists')
                    return ''
                else
                if (res.toLowerCase() == 'rem')
                    return 'R.E.M'
                else
                    return res;
            }

            var url = 'https://open.spotify.com/search/' + encodeURIComponent(app.utils.getLingBase(item.title) + ' ' + checkArtist(item.artist));
            window.uitools.openWeb(url);
        }
    },
    {
        id: 99,
        order: 99,
        title: _('Library'),
        execute: function (type, prop, item) {
            if (navigationHandlers[prop])
                navigationHandlers[prop].navigate(item[prop]);
        }
    }];


var handleShortcut = function (shortcut, type, prop, item) {
    var shortcutExecuted = false;
    for (var i = 0; i < TrackShortcuts.length; i++) {
        if (TrackShortcuts[i].id === shortcut) {
            if (TrackShortcuts[i].execute) {
                TrackShortcuts[i].execute(type, prop, item);
                shortcutExecuted = true;
            }
            break;
        }
    }
    if (!shortcutExecuted) {
        TrackShortcuts[0].execute(type, prop, item);
    }
};

window.uitools.tracklistFieldDefs.title.shortcutFunc = function (item, shortcutID) {
    handleShortcut(shortcutID, 'title', 'title', item);
}

window.uitools.tracklistFieldDefs.artist.shortcutFunc = function (item, shortcutID) {
    handleShortcut(shortcutID, 'artist', 'artist', item);
}

window.uitools.tracklistFieldDefs.album.shortcutFunc = function (item, shortcutID) {
    handleShortcut(shortcutID, 'album', 'album', item);
}

window.uitools.tracklistFieldDefs.albumArtist.shortcutFunc = function (item, shortcutID) {
    handleShortcut(shortcutID, 'albumArtist', 'albumArtist', item);
}

window.uitools.tracklistFieldDefs.series.shortcutFunc = function (item, shortcutID) {
    handleShortcut(shortcutID, 'series', 'album', item);
}

TrackListView.prototype.override({
    initialize: function ($super, elem, params) {
        $super(elem, params);
        this._showShortcuts = true;

        var loadSettings = () => {
            var sett = settings.get('Options');
            this._activeShortcut = sett.Options.ActiveTrackShortcutType;
        };
        loadSettings();

        this.localListen(settings.observer, 'change', () => {
            loadSettings();
        });
    },
});

TrackListView.prototype.getShortcutContextMenu = (parent, column) => {
    var presetColumns = [];
    TrackShortcuts.sort(function (i1, i2) {
        return i1.order - i2.order;
    });
    forEach(TrackShortcuts, function (shortcut, idx) {
        presetColumns.push({
            action: {
                title: shortcut.title,
                icon: shortcut.icon,
                execute: function () {
                    if (parent.parentElement.itemIndex >= 0) {
                        var LV = parent.parentElement.parentListView;
                        var item = undefined;
                        LV.dataSource.locked(function () {
                            item = LV.dataSource.getValue(parent.parentElement.itemIndex);
                        });
                        column.shortcutFunc(item, shortcut.id);
                    }
                }
            },
            grouporder: 10
        });
    });
    return new Menu(presetColumns, {
        parent: parent
    });
}
